about summary refs log tree commit diff
path: root/users/grfn/xanthous/src/Xanthous/Data/App.hs
diff options
context:
space:
mode:
Diffstat (limited to 'users/grfn/xanthous/src/Xanthous/Data/App.hs')
-rw-r--r--users/grfn/xanthous/src/Xanthous/Data/App.hs4
1 files changed, 3 insertions, 1 deletions
diff --git a/users/grfn/xanthous/src/Xanthous/Data/App.hs b/users/grfn/xanthous/src/Xanthous/Data/App.hs
index a2cfcb8001..13c4b5d610 100644
--- a/users/grfn/xanthous/src/Xanthous/Data/App.hs
+++ b/users/grfn/xanthous/src/Xanthous/Data/App.hs
@@ -16,7 +16,9 @@ import Xanthous.Util.QuickCheck
 
 -- | Enum for "panels" displayed in the game's UI.
 data Panel
-  = -- | A panel displaying the character's inventory
+  = -- | A panel providing help with the game's commands
+    HelpPanel
+  | -- | A panel displaying the character's inventory
     InventoryPanel
   | -- | A panel describing an item in the inventory in detail
     --